==> openshift-model-operatorhub-5.10.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/CatalogSourceStatusFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface CatalogSourceStatusFluent<A extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildConfigMapReference instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.ConfigMapResourceReference getConfigMapReference();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.ConfigMapResourceReference buildConfigMapReference();
  public A withConfigMapReference(io.fabric8.openshift.api.model.operatorhub.v1alpha1.ConfigMapResourceReference configMapReference);
  public java.lang.Boolean hasConfigMapReference();
  public A withNewConfigMapReference(java.lang.String lastUpdateTime,java.lang.String name,java.lang.String namespace,java.lang.String resourceVersion,java.lang.String uid);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent.ConfigMapReferenceNested<A> withNewConfigMapReference();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent.ConfigMapReferenceNested<A> withNewConfigMapReferenceLike(io.fabric8.openshift.api.model.operatorhub.v1alpha1.ConfigMapResourceReference item);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent.ConfigMapReferenceNested<A> editConfigMapReference();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent.ConfigMapReferenceNested<A> editOrNewConfigMapReference();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent.ConfigMapReferenceNested<A> editOrNewConfigMapReferenceLike(io.fabric8.openshift.api.model.operatorhub.v1alpha1.ConfigMapResourceReference item);
  
  /**
   * This method has been deprecated, please use method buildConnectionState instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.GRPCConnectionState getConnectionState();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.GRPCConnectionState buildConnectionState();
  public A withConnectionState(io.fabric8.openshift.api.model.operatorhub.v1alpha1.GRPCConnectionState connectionState);
  public java.lang.Boolean hasConnectionState();
  public A withNewConnectionState(java.lang.String address,java.lang.String lastConnect,java.lang.String lastObservedState);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent.ConnectionStateNested<A> withNewConnectionState();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent.ConnectionStateNested<A> withNewConnectionStateLike(io.fabric8.openshift.api.model.operatorhub.v1alpha1.GRPCConnectionState item);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent.ConnectionStateNested<A> editConnectionState();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent.ConnectionStateNested<A> editOrNewConnectionState();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent.ConnectionStateNested<A> editOrNewConnectionStateLike(io.fabric8.openshift.api.model.operatorhub.v1alpha1.GRPCConnectionState item);
  public java.lang.String getLatestImageRegistryPoll();
  public A withLatestImageRegistryPoll(java.lang.String latestImageRegistryPoll);
  public java.lang.Boolean hasLatestImageRegistryPoll();
  
  /**
   * Method is deprecated. use withLatestImageRegistryPoll instead.
   */
  @java.lang.Deprecated
  public A withNewLatestImageRegistryPoll(java.lang.String arg0);
  public java.lang.String getMessage();
  public A withMessage(java.lang.String message);
  public java.lang.Boolean hasMessage();
  
  /**
   * Method is deprecated. use withMessage instead.
   */
  @java.lang.Deprecated
  public A withNewMessage(java.lang.String arg0);
  public java.lang.String getReason();
  public A withReason(java.lang.String reason);
  public java.lang.Boolean hasReason();
  
  /**
   * Method is deprecated. use withReason instead.
   */
  @java.lang.Deprecated
  public A withNewReason(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildRegistryService instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryServiceStatus getRegistryService();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryServiceStatus buildRegistryService();
  public A withRegistryService(io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryServiceStatus registryService);
  public java.lang.Boolean hasRegistryService();
  public A withNewRegistryService(java.lang.String createdAt,java.lang.String port,java.lang.String protocol,java.lang.String serviceName,java.lang.String serviceNamespace);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent.RegistryServiceNested<A> withNewRegistryService();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent.RegistryServiceNested<A> withNewRegistryServiceLike(io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryServiceStatus item);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent.RegistryServiceNested<A> editRegistryService();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent.RegistryServiceNested<A> editOrNewRegistryService();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent.RegistryServiceNested<A> editOrNewRegistryServiceLike(io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryServiceStatus item);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface ConfigMapReferenceNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.operatorhub.v1alpha1.ConfigMapResourceReferenceFluent<io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent.ConfigMapReferenceNested<N>>{
    public N and();
    public N endConfigMapReference();
    
  }
  public interface ConnectionStateNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.operatorhub.v1alpha1.GRPCConnectionStateFluent<io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent.ConnectionStateNested<N>>{
    public N and();
    public N endConnectionState();
    
  }
  public interface RegistryServiceNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryServiceStatusFluent<io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent.RegistryServiceNested<N>>{
    public N and();
    public N endRegistryService();
    
  }
  
}

==> openshift-model-operatorhub-5.12.0-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/CatalogSourceStatusFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.Condition;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface CatalogSourceStatusFluent<A extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToConditions(java.lang.Integer index,io.fabric8.kubernetes.api.model.Condition item);
  public A setToConditions(java.lang.Integer index,io.fabric8.kubernetes.api.model.Condition item);
  public A addToConditions(io.fabric8.kubernetes.api.model.Condition... items);
  public A addAllToConditions(java.util.Collection<io.fabric8.kubernetes.api.model.Condition> items);
  public A removeFromConditions(io.fabric8.kubernetes.api.model.Condition... items);
  public A removeAllFromConditions(java.util.Collection<io.fabric8.kubernetes.api.model.Condition> items);
  public java.util.List<io.fabric8.kubernetes.api.model.Condition> getConditions();
  public io.fabric8.kubernetes.api.model.Condition getCondition(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.Condition getFirstCondition();
  public io.fabric8.kubernetes.api.model.Condition getLastCondition();
  public io.fabric8.kubernetes.api.model.Condition getMatchingCondition(java.util.function.Predicate<io.fabric8.kubernetes.api.model.Condition> predicate);
  public java.lang.Boolean hasMatchingCondition(java.util.function.Predicate<io.fabric8.kubernetes.api.model.Condition> predicate);
  public A withConditions(java.util.List<io.fabric8.kubernetes.api.model.Condition> conditions);
  public A withConditions(io.fabric8.kubernetes.api.model.Condition... conditions);
  public java.lang.Boolean hasConditions();
  
  /**
   * This method has been deprecated, please use method buildConfigMapReference instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.ConfigMapResourceReference getConfigMapReference();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.ConfigMapResourceReference buildConfigMapReference();
  public A withConfigMapReference(io.fabric8.openshift.api.model.operatorhub.v1alpha1.ConfigMapResourceReference configMapReference);
  public java.lang.Boolean hasConfigMapReference();
  public A withNewConfigMapReference(java.lang.String lastUpdateTime,java.lang.String name,java.lang.String namespace,java.lang.String resourceVersion,java.lang.String uid);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent.ConfigMapReferenceNested<A> withNewConfigMapReference();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent.ConfigMapReferenceNested<A> withNewConfigMapReferenceLike(io.fabric8.openshift.api.model.operatorhub.v1alpha1.ConfigMapResourceReference item);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent.ConfigMapReferenceNested<A> editConfigMapReference();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent.ConfigMapReferenceNested<A> editOrNewConfigMapReference();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent.ConfigMapReferenceNested<A> editOrNewConfigMapReferenceLike(io.fabric8.openshift.api.model.operatorhub.v1alpha1.ConfigMapResourceReference item);
  
  /**
   * This method has been deprecated, please use method buildConnectionState instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.GRPCConnectionState getConnectionState();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.GRPCConnectionState buildConnectionState();
  public A withConnectionState(io.fabric8.openshift.api.model.operatorhub.v1alpha1.GRPCConnectionState connectionState);
  public java.lang.Boolean hasConnectionState();
  public A withNewConnectionState(java.lang.String address,java.lang.String lastConnect,java.lang.String lastObservedState);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent.ConnectionStateNested<A> withNewConnectionState();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent.ConnectionStateNested<A> withNewConnectionStateLike(io.fabric8.openshift.api.model.operatorhub.v1alpha1.GRPCConnectionState item);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent.ConnectionStateNested<A> editConnectionState();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent.ConnectionStateNested<A> editOrNewConnectionState();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent.ConnectionStateNested<A> editOrNewConnectionStateLike(io.fabric8.openshift.api.model.operatorhub.v1alpha1.GRPCConnectionState item);
  public java.lang.String getLatestImageRegistryPoll();
  public A withLatestImageRegistryPoll(java.lang.String latestImageRegistryPoll);
  public java.lang.Boolean hasLatestImageRegistryPoll();
  
  /**
   * Method is deprecated. use withLatestImageRegistryPoll instead.
   */
  @java.lang.Deprecated
  public A withNewLatestImageRegistryPoll(java.lang.String arg0);
  public java.lang.String getMessage();
  public A withMessage(java.lang.String message);
  public java.lang.Boolean hasMessage();
  
  /**
   * Method is deprecated. use withMessage instead.
   */
  @java.lang.Deprecated
  public A withNewMessage(java.lang.String arg0);
  public java.lang.String getReason();
  public A withReason(java.lang.String reason);
  public java.lang.Boolean hasReason();
  
  /**
   * Method is deprecated. use withReason instead.
   */
  @java.lang.Deprecated
  public A withNewReason(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildRegistryService instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryServiceStatus getRegistryService();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryServiceStatus buildRegistryService();
  public A withRegistryService(io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryServiceStatus registryService);
  public java.lang.Boolean hasRegistryService();
  public A withNewRegistryService(java.lang.String createdAt,java.lang.String port,java.lang.String protocol,java.lang.String serviceName,java.lang.String serviceNamespace);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent.RegistryServiceNested<A> withNewRegistryService();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent.RegistryServiceNested<A> withNewRegistryServiceLike(io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryServiceStatus item);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent.RegistryServiceNested<A> editRegistryService();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent.RegistryServiceNested<A> editOrNewRegistryService();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent.RegistryServiceNested<A> editOrNewRegistryServiceLike(io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryServiceStatus item);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface ConfigMapReferenceNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.operatorhub.v1alpha1.ConfigMapResourceReferenceFluent<io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent.ConfigMapReferenceNested<N>>{
    public N and();
    public N endConfigMapReference();
    
  }
  public interface ConnectionStateNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.operatorhub.v1alpha1.GRPCConnectionStateFluent<io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent.ConnectionStateNested<N>>{
    public N and();
    public N endConnectionState();
    
  }
  public interface RegistryServiceNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryServiceStatusFluent<io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent.RegistryServiceNested<N>>{
    public N and();
    public N endRegistryService();
    
  }
  
}
